<?php

namespace Drupal\google_geochart\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a 'GeoChartBlock' block.
 *
 * @Block(
 *  id = "geo_chart_block",
 *  admin_label = @Translation("Geo chart block"),
 * )
 */
class GeoChartBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
                  'google_visualization_array_to_da' => ['Country', 'Popularity'], ['Germany', 200], ['United States', 300], ['Brazil', 400], ['Canada', 500], ['France', 600], ['RU', 700],
          ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form['google_mapsapikey'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Google mapsApiKey'),
    '#description' => $this->t('See https://developers.google.com/chart/interactive/docs/basic_load_libs#load-settings'),
      '#default_value' => $this->configuration['google_mapsapikey'],
      '#maxlength' => 256,
      '#size' => 64,
      '#weight' => '0',
    ];
    $form['google_visualization_array_to_da'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Google visualization array to DataTable'),
    '#description' => $this->t('Google visualization array to DataTable'),
      '#default_value' => $this->configuration['google_visualization_array_to_da'],
      '#weight' => '0',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $this->configuration['google_mapsapikey'] = $form_state->getValue('google_mapsapikey');
    $this->configuration['google_visualization_array_to_da'] = $form_state->getValue('google_visualization_array_to_da');
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $build = [];
    //$build['geo_chart_block_google_mapsapikey']['#markup'] = '<p>' . $this->configuration['google_mapsapikey'] . '</p>';
    //$build['geo_chart_block_google_visualization_array_to_da']['#markup'] = '<p>' . $this->configuration['google_visualization_array_to_da'] . '</p>';
    $build = [
      '#theme' => 'google_geochart',
      '#attached' => array(
        'library' => array(
          'google_geochart/google_geochart',
        ),
      ),
    ];
    return $build;
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheMaxAge() {
    return 0;
  }

}
